import { useCallback, useEffect, useMemo, useRef, useState } from 'react';
import deepEqual from 'deep-equal';
import { getConfiguration, getThemeData, onConfigurationChanged, monaco } from '@codingame/monaco-editor-wrapper';
const standaloneThemeService = monaco.extra.StandaloneServices.get(monaco.editor.IStandaloneThemeService);
export function useThemeData() {
    const [themeName, setThemeName] = useState(standaloneThemeService.getColorTheme().themeName);
    const updateTheme = (theme) => {
        setThemeName(theme.themeName);
    };
    useEffect(() => {
        const disposable = standaloneThemeService.onDidColorThemeChange(updateTheme);
        updateTheme(standaloneThemeService.getColorTheme());
        return () => {
            disposable.dispose();
        };
    }, []);
    return useMemo(() => {
        return getThemeData(themeName);
    }, [themeName]);
}
export function useUserConfiguration(programmingLanguageId) {
    const [userConfiguration, setUserConfiguration] = useState(() => getConfiguration());
    useEffect(() => {
        const updateOptions = () => {
            setUserConfiguration(getConfiguration(programmingLanguageId));
        };
        const configurationChangeDisposable = onConfigurationChanged(updateOptions);
        return () => {
            configurationChangeDisposable.dispose();
        };
    }, [programmingLanguageId]);
    return userConfiguration;
}
export function useLastValueRef(value) {
    const ref = useRef(value);
    ref.current = value;
    return ref;
}
export function useLastVersion(func) {
    const ref = useRef(func);
    useEffect(() => {
        ref.current = func;
    }, [func]);
    return useCallback((...args) => {
        return ref.current(...args);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
}
export function usePrevious(value) {
    const ref = useRef();
    useEffect(() => {
        ref.current = value;
    }, [value]);
    return ref.current;
}
export function useDeepMemo(memoFn, deps, isEqual = deepEqual) {
    const ref = useRef();
    if (ref.current == null || !isEqual(deps, ref.current.deps)) {
        ref.current = { deps, value: memoFn() };
    }
    return ref.current.value;
}
//# sourceMappingURL=hooks.js.map